#!/bin/sh

BASEPATH=$(cd `dirname $0`; pwd)
VERSION=1.7

VENDORPATH=/vendor/wiimu
VER_CTRL_FILE=yamaha_ver.txt
SYS_VER=/system/workdir/MVver
MCU_VER=/tmp/mcu_ver
FORCE_UPG_FLAG=/tmp/usb_upg_force
REBOOT_CTRL_FILE=/tmp/usb_upgrade_reboot
MODULE_UP_IMG=update.zip
MODULE_UP_IMG2=update.bin
MCU_UP_IMG=001446-0515.bin
MODULE_TARGET=
MCU_TARGET=
UPGRADE_TOOL=/bin/upgrade_app
NEED_REBOOT=

check_module_ver()
{
	MODULE_RESULT=0
	
	if [ -f ${FORCE_UPG_FLAG} ];
	then
		echo FORCE UPG!
		MODULE_RESULT=1
		return $MODULE_RESULT
	fi	
	
	if [ -f ${BASEPATH}/${VER_CTRL_FILE} ]; 
	then
		echo ${BASEPATH}/${VER_CTRL_FILE} found
		VER_CTRL_MODULE=`sed -n '/MODULE=/p' ${BASEPATH}/${VER_CTRL_FILE} | sed 's/MODULE=//g'`
		MVVER=`sed -n '6'p $SYS_VER`
		if [ $VER_CTRL_MODULE -gt $MVVER ];
		then
			MODULE_RESULT=1
		else
			MODULE_RESULT=0
		fi
	fi
	echo  $MODULE_RESULT  "$VER_CTRL_MODULE"  "$MVVER"
	return $MODULE_RESULT
}

check_mcu_ver()
{
	MCU_RESULT=0
	
	if [ -f ${FORCE_UPG_FLAG} ];
	then
		echo FORCE UPG!
		MCU_RESULT=1
		return $MCU_RESULT
	fi	
	
	if [ -f ${BASEPATH}/${VER_CTRL_FILE} ]; 
	then
		echo ${BASEPATH}/${VER_CTRL_FILE} found
		VER_CTRL_MCU=`sed -n '/MCU=/p' ${BASEPATH}/${VER_CTRL_FILE} | sed 's/MCU=//g'`
		MCUVER=`cat $MCU_VER`
		if [ $VER_CTRL_MCU -gt $MCUVER ];
		then
			MCU_RESULT=1
		else
			MCU_RESULT=0
		fi
	fi
	echo  $MCU_RESULT  "$VER_CTRL_MCU"  "$MCUVER"
	return $MCU_RESULT
}

echo =================================================
echo YAMAHA USB upgrade tool
echo version:$VERSION
echo =================================================
echo Start...
echo Check upgrade image exist

if [ -f ${BASEPATH}/${MODULE_UP_IMG} ]; 
then
	echo ${MODULE_UP_IMG} found
	MODULE_TARGET=${BASEPATH}/${MODULE_UP_IMG}
elif [ -f ${BASEPATH}/${MODULE_UP_IMG2} ]; 
then
	echo ${MODULE_UP_IMG2} found
	MODULE_TARGET=${BASEPATH}/${MODULE_UP_IMG2}
elif [ -f ${VENDORPATH}/${MODULE_UP_IMG} ]; 
then
	echo ${MODULE_UP_IMG} found
	MODULE_TARGET=${VENDORPATH}/${MODULE_UP_IMG}
fi

echo ${MODULE_TARGET}

if [ ! -n "$MODULE_TARGET" ]; then 
  	echo not Module image found!
else
		check_module_ver
		if [ $MODULE_RESULT != 0 ]; then
			echo ${MODULE_TARGET} will be upgraded
			LD_LIBRARY_PATH=/system/workdir/lib:$LD_LIBRARY_PATH /system/workdir/bin/smplayer /system/workdir/misc/Voice-prompt/us/updatewait.mp3
			LD_LIBRARY_PATH=/system/workdir/lib:$LD_LIBRARY_PATH /system/workdir/bin/localSendSocket  2  BurningImage
			${UPGRADE_TOOL} ${MODULE_TARGET}  
			NEED_REBOOT=1
		else
			echo Version control block the ${MODULE_TARGET} upgrade!
		fi
fi

echo Check if mcu upgrade image exist
if [ -f ${BASEPATH}/${MCU_UP_IMG} ]; 
then
	echo ${MCU_UP_IMG} found
	MCU_TARGET=${BASEPATH}/${MCU_UP_IMG}
elif [ -f ${VENDORPATH}/${MCU_UP_IMG} ]; 
then
	echo ${MCU_UP_IMG} found
	MCU_TARGET=${VENDORPATH}/${MCU_UP_IMG}
fi

echo ${MCU_TARGET}

if [ ! -n "$MCU_TARGET" ]; then 
  	echo not MCU image found!
else
		check_mcu_ver
		if [  $MCU_RESULT  !=  0  ]; then
			echo ${MCU_TARGET} found
			rm -rf /tmp/${MCU_UP_IMG}
			cp -rf ${MCU_TARGET} /tmp/${MCU_UP_IMG}
			sync
			LD_LIBRARY_PATH=/system/workdir/lib:$LD_LIBRARY_PATH /system/workdir/bin/smplayer /system/workdir/misc/Voice-prompt/us/updatewait.mp3
			LD_LIBRARY_PATH=/system/workdir/lib:$LD_LIBRARY_PATH /system/workdir/bin/localSendSocket  2  BurningImage
			LD_LIBRARY_PATH=/system/workdir/lib:$LD_LIBRARY_PATH /system/workdir/bin/a01localupdate /tmp/${MCU_UP_IMG}
			NEED_REBOOT=1
		else
			echo Version control block the ${MCU_UP_IMG} upgrade!
		fi
fi


if [ ! -n "$NEED_REBOOT" ]; then 
		echo not need reboot
else
		echo reboot NOW!!!
		echo 1 > $REBOOT_CTRL_FILE
		sync
		#reboot
fi

echo =================================================
echo Done!
echo =================================================
